<?php

declare(strict_types=1);

namespace Drupal\cache_pilot\Connection;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\cache_pilot\Exception\InvalidConfigurationException;
use Drupal\cache_pilot\Exception\MissingConnectionTypeException;
use Drupal\cache_pilot\Utils\HostHelper;
use hollodotme\FastCGI\Interfaces\ConfiguresSocketConnection;
use hollodotme\FastCGI\SocketConnections\NetworkSocket;
use hollodotme\FastCGI\SocketConnections\UnixDomainSocket;

/**
 * Prepares socket connection.
 */
final readonly class SocketConnectionBuilder {

  public function __construct(
    private ConfigFactoryInterface $configFactory,
  ) {}

  /**
   * Prepares connection to socket.
   *
   * @return \hollodotme\FastCGI\Interfaces\ConfiguresSocketConnection
   *   The socket connection configuration.
   */
  public function build(): ConfiguresSocketConnection {
    $settings = $this->configFactory->get('cache_pilot.settings');

    if (!$settings->get('connection.type')) {
      throw new MissingConnectionTypeException();
    }

    if ($settings->get('connection.type') === 'tcp') {
      \assert(\is_string($settings->get('connection.host')));
      $host_info = HostHelper::parseHostInfo($settings->get('connection.host'));
      return new NetworkSocket($host_info['host'], $host_info['port']);
    }

    if ($settings->get('connection.type') !== 'uds') {
      \assert(\is_string($settings->get('connection.uds_path')));
      return new UnixDomainSocket($settings->get('connection.uds_path'));
    }

    throw new InvalidConfigurationException('The connection type is not supported.');
  }

}
