<?php

declare(strict_types=1);

namespace Drupal\cache_pilot\Controller;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\cache_pilot\Cache\ApcuCache;
use Drupal\cache_pilot\Cache\OpcacheCache;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a controller for cache statistics dashboard.
 */
final readonly class DashboardController implements ContainerInjectionInterface {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get(ApcuCache::class),
      $container->get(OpcacheCache::class),
    );
  }

  /**
   * Constructs a new DashboardController.
   */
  public function __construct(
    private ApcuCache $apcu,
    private OpcacheCache $opcache,
  ) {}

  /**
   * Returns the cache statistics dashboard.
   */
  public function __invoke(): array {
    $build = [
      '#theme' => 'cache_pilot_dashboard',
    ];

    $apcu_statistics = $this->apcu->statistics();
    if ($apcu_statistics) {
      $build['#apcu'] = [
        '#theme' => 'cache_pilot_apcu_statistics',
        '#statistics' => $apcu_statistics,
      ];
    }

    $opcache_statistics = $this->opcache->statistics();
    if ($opcache_statistics) {
      $build['#opcache'] = [
        '#theme' => 'cache_pilot_opcache_statistics',
        '#statistics' => $opcache_statistics,
      ];
    }

    if (!isset($build['#apcu']) && !isset($build['#opcache'])) {
      return [
        '#markup' => new TranslatableMarkup('Looks like there is a problem with the connection to FastCGI.'),
      ];
    }

    return $build;
  }

}
