<?php

declare(strict_types=1);

namespace Drupal\cache_pilot\Utils;

/**
 * Provides helpers for host values.
 */
final readonly class HostHelper {

  /**
   * Parses host information.
   *
   * @param string $host
   *   The host to parse, port should be separated by colon.
   *
   * @return array{
   *   'host': string,
   *   'port': int,
   *   }
   */
  public static function parseHostInfo(string $host): array {
    $info = parse_url($host);

    if (!isset($info['host']) || !isset($info['port'])) {
      $message = sprintf(
        "The provided host should be in format '[address]:[port]', %s provided",
        $host,
      );
      throw new \InvalidArgumentException($message);
    }

    return $info;
  }

}
